@@ -4,7 +4,7 @@
 
 #include <kmessagebox.h>
 #include <kdebug.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <ktempfile.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -34,7 +34,7 @@ Board::~Board()
 
 void Board::init(int type)
 {
-	QList<QString> schemes;
+	QPtrList<QString> schemes;
 	int i;
 
 	kdDebug() << "Load scheme of type: " << type << endl;
@@ -112,7 +112,7 @@ void Board::deleteTracks()
 	}
 }
 
-QStringList Board::list()
+QStringList Board::list(bool autoreplace)
 {
 	QStringList l;
 	QListViewItem *item;
@@ -122,7 +122,7 @@ QStringList Board::list()
 	{
 		for(int i = 0; i < columns(); i++)
 			l.append(item->text(i));
-		m_replace = item;
+		if(autoreplace) m_replace = item;
 	}
 	return l;
 }
