@@ -16,7 +16,7 @@ class Board : public KListView
 		void clear();
 		void save(QString filename);
 		void load(QString filename);
-		QStringList list();
+		QStringList list(bool autoreplace);
 		QString type();
 
 	public slots:
