@@ -3,7 +3,7 @@
 #include "scheme.h"
 
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 
 #include <qlayout.h>
@@ -13,7 +13,7 @@
 #include <qpixmap.h>
 
 Entry::Entry(QWidget *parent, const char *name)
-: QWidget(parent, name)
+: QDialog(parent, name)
 {
 	QLabel *title;
 
@@ -27,7 +27,7 @@ Entry::Entry(QWidget *parent, const char *name)
 
 void Entry::init(int type)
 {
-	QList<QString> schemes;
+	QPtrList<QString> schemes;
 	int i;
 
 	schemes = Scheme::instance()->schemes();
@@ -42,7 +42,7 @@ void Entry::init(int type)
 		i++;
 	}
 
-	setCaption("Add a new track");
+	setCaption(i18n("Add a new track"));
 	resize(300, 200);
 	show();
 }
@@ -83,15 +83,17 @@ void Entry::init2(QString type)
 		if(icons) it2++;
 	}
 
-	QPushButton *ok, *cancel;
 	ok = new QPushButton(i18n("Add"), this);
+	clearall = new QPushButton(i18n("Clear all"), this);
 	cancel = new QPushButton(i18n("Cancel"), this);
 
 	connect(ok, SIGNAL(clicked()), SLOT(slotAccept()));
-	connect(cancel, SIGNAL(clicked()), SLOT(close()));
+	connect(clearall, SIGNAL(clicked()), SLOT(slotClearAll()));
+	connect(cancel, SIGNAL(clicked()), SLOT(reject()));
 
 	hbox2 = new QHBoxLayout(vbox, 5);
 	hbox2->add(ok);
+	hbox2->add(clearall);
 	hbox2->add(cancel);
 }
 
@@ -107,7 +109,7 @@ void Entry::slotAccept()
 		list.append(QString(ed->text()));
 
 	emit signalNewTrack(list);
-	close();
+	accept();
 }
 
 void Entry::fill(QStringList list)
@@ -125,5 +127,17 @@ void Entry::fill(QStringList list)
 			it++;
 		}
 	}
+
+	ok->setText(i18n("Modify"));
+}
+
+void Entry::slotClearAll()
+{
+	QLineEdit *ed;
+	
+	ed = editlist.first();
+	if(ed) ed->setFocus();
+	for(ed = editlist.first(); ed; ed = editlist.next())
+		ed->setText(QString::null);
 }
 
