@@ -1,15 +1,16 @@
 #ifndef ENTRY_H
 #define ENTRY_H
 
-#include <qwidget.h>
+#include <qdialog.h>
 #include <qstringlist.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 class QLineEdit;
 class QVBoxLayout;
 class QGridLayout;
+class QPushButton;
 
-class Entry : public QWidget
+class Entry : public QDialog
 {
 	Q_OBJECT
 	public:
@@ -21,6 +22,7 @@ class Entry : public QWidget
 
 	public slots:
 		void slotAccept();
+		void slotClearAll();
 
 	signals:
 		void signalNewTrack(QStringList list);
@@ -28,7 +30,8 @@ class Entry : public QWidget
 	private:
 		QVBoxLayout *vbox;
 		QGridLayout *grid;
-		QList<QLineEdit> editlist;
+		QPtrList<QLineEdit> editlist;
+		QPushButton *ok, *cancel, *clearall;
 };
 
 #endif
