@@ -1,7 +1,7 @@
 #include "toplevel.h"
 #include "config.h"
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -12,9 +12,9 @@ int main(int argc, char **argv)
 	Toplevel *top;
 	KAboutData *about;
 
-	about = new KAboutData("novinyl", I18N_NOOP("KDE Music Database"), VERSION,
-		I18N_NOOP("Small parent-friendly music management for the KDE"),
-		KAboutData::License_GPL, "Copyright (C) 2001 Josef Spillner", NULL,
+	about = new KAboutData("novinyl", I18N_NOOP("Lightweight KDE Desktop Database"), VERSION,
+		I18N_NOOP("A flat database frontend to store collections of any kind."),
+		KAboutData::License_GPL, "Copyright (C) 2001, 2002 Josef Spillner", NULL,
 		"http://mindx.sourceforge.net/novinyl", "dr_maux@users.sourceforge.net");
 	about->addAuthor("Josef Spillner", "Programming", "dr_maux@users.sourceforge.net");
 
