@@ -10,7 +10,7 @@
 #include <qcombobox.h>
 
 NewDB::NewDB(QWidget *parent, const char *name)
-: QWidget(parent, name)
+: QDialog(parent, name)
 {
 	QVBoxLayout *vbox;
 	QHBoxLayout *hbox;
@@ -18,7 +18,7 @@ NewDB::NewDB(QWidget *parent, const char *name)
 	QPushButton *ok, *cancel;
 
 	dbtypes = new QComboBox(this);
-	QList<QString> l = Scheme::instance()->schemes();
+	QPtrList<QString> l = Scheme::instance()->schemes();
 	for(QString *s = l.first(); s; s = l.next())
 		dbtypes->insertItem(*s);
 
@@ -35,7 +35,7 @@ NewDB::NewDB(QWidget *parent, const char *name)
 	hbox->add(cancel);
 
 	connect(ok, SIGNAL(clicked()), SLOT(slotNewDB()));
-	connect(cancel, SIGNAL(clicked()), SLOT(close()));
+	connect(cancel, SIGNAL(clicked()), SLOT(reject()));
 
 	resize(300, 100);
 	setCaption(i18n("New database"));
@@ -49,5 +49,6 @@ NewDB::~NewDB()
 void NewDB::slotNewDB()
 {
 	emit signalNewDB(dbtypes->currentText());
+	accept();
 }
 
