@@ -1,11 +1,11 @@
 #ifndef NEWDB_H
 #define NEWDB_H
 
-#include <qwidget.h>
+#include <qdialog.h>
 
 class QComboBox;
 
-class NewDB : public QWidget
+class NewDB : public QDialog
 {
 	Q_OBJECT
 	public:
