@@ -1,6 +1,6 @@
 #include "scheme.h"
 
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 #include <ksimpleconfig.h>
 
@@ -26,7 +26,7 @@ void Scheme::init()
 	const QStringList *icon, *column;
 	KStandardDirs d;
 
-	QStringList s = d.findAllResources("data", "*.scheme", true);
+	QStringList s = d.findAllResources("data", "novinyl/*.scheme", true);
 	for(QStringList::Iterator it = s.begin(); it != s.end(); it++)
 	{
 		kdDebug() << (*it) << endl;
@@ -45,7 +45,7 @@ void Scheme::init()
 	}
 }
 
-QList<QString> Scheme::schemes()
+QPtrList<QString> Scheme::schemes()
 {
 	return m_schemelist;
 }
