@@ -2,7 +2,7 @@
 #define NOVINYL_SCHEME_H
 
 #include <qdict.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qstringlist.h>
 
@@ -11,14 +11,14 @@ class Scheme
 	public:
 		static Scheme* instance();
 		void init();
-		QList<QString> schemes();
+		QPtrList<QString> schemes();
 		QStringList* icons(QString scheme);
 		QStringList* columns(QString scheme);
 
 	private:
 		Scheme();
 		~Scheme();
-		QList<QString> m_schemelist;
+		QPtrList<QString> m_schemelist;
 		QDict<QStringList> m_iconlist;
 		QDict<QStringList> m_columnlist;
 		
