@@ -9,7 +9,7 @@
 #include <kpopupmenu.h>
 #include <kmenubar.h>
 #include <ksimpleconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 
 Toplevel::Toplevel()
@@ -17,8 +17,6 @@ Toplevel::Toplevel()
 {
 	KPopupMenu *menu_file;
 
-	entry = NULL;
-	newdb = NULL;
 	Scheme::instance()->init();
 
 	menu_file = new KPopupMenu(this);
@@ -33,12 +31,16 @@ Toplevel::Toplevel()
 	menu_entry = new KPopupMenu(this);
 	menu_entry->insertItem(i18n("New"), menuentrynew);
 	menu_entry->insertItem(i18n("Modify"), menuentrymodify);
+	menu_entry->insertItem(i18n("Duplicate selected"), menuentryduplicate);
 	menu_entry->insertItem(i18n("Delete selected"), menuentrydelete);
+	menu_entry->insertSeparator();
+	menu_entry->insertItem(i18n("Unselect all"), menuentryclear);
 	menu_entry->setEnabled(false);
 
-	menuBar()->insertItem(i18n("File"), menu_file);
-	menuBar()->insertItem(i18n("Entries"), menu_entry);
+	menuBar()->insertItem(i18n("File"), menu_file, menu_file_id);
+	menuBar()->insertItem(i18n("Entries"), menu_entry, menu_entry_id);
 	menuBar()->insertItem(i18n("Help"), helpMenu());
+	menuBar()->setItemEnabled(menu_entry_id, false);
 
 	board = new Board(this);
 	setCentralWidget(board);
@@ -54,89 +56,96 @@ Toplevel::~Toplevel()
 {
 }
 
+void Toplevel::menuNewDB()
+{
+	NewDB newdb;
+
+	connect(&newdb, SIGNAL(signalNewDB(QString)), SLOT(slotNewDB(QString)));
+	newdb.exec();
+}
+
+void Toplevel::menuEntryNew()
+{
+	Entry entry;
+
+	connect(&entry, SIGNAL(signalNewTrack(QStringList)), board, SLOT(slotNewTrack(QStringList)));
+	entry.init2(m_type);
+	entry.exec();
+}
+
+void Toplevel::menuEntryEdit()
+{
+	Entry entry;
+	QStringList l;
+
+	connect(&entry, SIGNAL(signalNewTrack(QStringList)), board, SLOT(slotNewTrack(QStringList)));
+	entry.init2(m_type);
+
+	l = board->list(true);
+	if(l.count())
+	{
+		entry.fill(l);
+		entry.show();
+	}
+	entry.exec();
+}
+
 void Toplevel::slotMenu(int id)
 {
 	QString x;
-	QStringList l;
 
 	switch(id)
 	{
 		case menufilenew:
-			if(!newdb)
-			{
-				newdb = new NewDB();
-				connect(newdb, SIGNAL(signalNewDB(QString)), SLOT(slotNewDB(QString)));
-			}
-			newdb->show();
+			menuNewDB();
 			break;
 		case menufileopen:
 			x = KFileDialog::getOpenFileName(QString::null,
-				"*.novinyl|Novinyl native (*.novinyl)\n*.ksp|KSpread export (*.ksp)");
+				i18n("*.novinyl|Novinyl native (*.novinyl)\n*.ksp|KSpread export (*.ksp)"));
 			if(!x.isEmpty())
 			{
 				menu_entry->setEnabled(true);
 				board->load(x);
 				m_type = board->type();
-				if(entry)
-				{
-					delete entry;
-					entry = NULL;
-				}
 			}
 			break;
 		case menufilesave:
-			x = KFileDialog::getSaveFileName(QString::null, "*.novinyl|Novinyl native (*.novinyl)");
+			x = KFileDialog::getSaveFileName(QString::null, i18n("*.novinyl|Novinyl native (*.novinyl)"));
 			if(!x.isEmpty()) board->save(x);
 			break;
 		case menufilesaveas:
 			x = KFileDialog::getSaveFileName(QString::null,
-				"*.novinyl|Novinyl native (*.novinyl)\n*.ksp|KSpread export (*.ksp)");
+				i18n("*.novinyl|Novinyl native (*.novinyl)\n*.ksp|KSpread export (*.ksp)"));
 			if(!x.isEmpty()) board->save(x);
 			break;
 		case menufilequit:
 			close();
 			break;
 		case menuentrynew:
-			if(!entry)
-			{
-				entry = new Entry();
-				entry->init2(m_type);
-				connect(entry, SIGNAL(signalNewTrack(QStringList)), board, SLOT(slotNewTrack(QStringList)));
-			}
-			entry->show();
+			menuEntryNew();
 			break;
 		case menuentrymodify:
-			if(!entry)
-			{
-				entry = new Entry();
-				entry->init2(m_type);
-				connect(entry, SIGNAL(signalNewTrack(QStringList)), board, SLOT(slotNewTrack(QStringList)));
-			}
-			l = board->list();
-			//entry->hide(); // make gcc happy :)
-			if(l.count())
-			{
-				entry->fill(l);
-				entry->show();
-			}
+			menuEntryEdit();
+			break;
+		case menuentryduplicate:
+			board->slotNewTrack(board->list(false));
 			break;
 		case menuentrydelete:
 			board->deleteTracks();
 			break;
+		case menuentryclear:
+			board->clearSelection();
+			break;
 	}
 }
 
 void Toplevel::slotNewDB(QString type)
 {
-	newdb->hide();
 	board->init2(type);
 	m_type = type;
 	board->clear();
+
 	menu_entry->setEnabled(true);
-	if(entry)
-	{
-		delete entry;
-		entry = NULL;
-	}
+	menuBar()->setItemEnabled(menu_entry_id, true);
 }
 
