@@ -6,8 +6,6 @@
 #include <qstringlist.h>
 
 class Board;
-class Entry;
-class NewDB;
 class Scheme;
 class KPopupMenu;
 
@@ -26,7 +24,14 @@ class Toplevel : public KMainWindow
 			menufilequit,
 			menuentrynew,
 			menuentrymodify,
-			menuentrydelete
+			menuentryduplicate,
+			menuentrydelete,
+			menuentryclear
+		};
+		enum MenuIds
+		{
+			menu_file_id,
+			menu_entry_id
 		};
 
 	public slots:
@@ -34,9 +39,11 @@ class Toplevel : public KMainWindow
 		void slotNewDB(QString type);
 
 	private:
+		void menuNewDB();
+		void menuEntryNew();
+		void menuEntryEdit();
+
 		Board *board;
-		Entry *entry;
-		NewDB *newdb;
 		Scheme *scheme;
 		QString m_type;
 		KPopupMenu *menu_entry;
